@@ -16,6 +16,7 @@
 from cfy_lint.yamllint_ext.autofix.truthy import fix_truthy
 from cfy_lint.yamllint_ext.autofix.colons import fix_colons
 from cfy_lint.yamllint_ext.autofix.indentation import fix_indentation
+from cfy_lint.yamllint_ext.autofix.brackets import fix_spaces_in_brackets
 from cfy_lint.yamllint_ext.autofix.trailing_spaces import fix_trailing_spaces
 from cfy_lint.yamllint_ext.autofix.deprecated_node_types import \
     fix_deprecated_node_types
@@ -31,3 +32,4 @@ def fix_problem(problem):
         fix_deprecated_node_types(problem)
         fix_deprecated_relationships(problem)
         fix_colons(problem)
+        fix_spaces_in_brackets(problem)
