@@ -17,9 +17,11 @@ import os
 import re
 from tempfile import NamedTemporaryFile
 
+from cfy_lint.cli import FixParamValue
 from cfy_lint.yamllint_ext import autofix
 from cfy_lint.yamllint_ext.autofix import utils
 from cfy_lint.yamllint_ext.autofix import colons
+from cfy_lint.yamllint_ext.autofix import brackets
 from cfy_lint.yamllint_ext.autofix import add_label
 from cfy_lint.yamllint_ext.autofix import indentation
 from cfy_lint.yamllint_ext.autofix import empty_lines
@@ -91,44 +93,58 @@ def test_get_indented_regex():
 def get_file(lines):
     fix_truthy_file = NamedTemporaryFile(delete=False)
     f = open(fix_truthy_file.name, 'w')
-    f.writelines(lines)
+    if isinstance(lines, str):
+        f.write(lines)
+    else:
+        f.writelines(lines)
     f.close()
     return f
 
 
 def test_fix_add_label():
-    lines = [
-        '  size:\n',
-        '  retry_after:\n',
-        '  env_name:\n',
+    content = """
+foo:
+  type: bar
+baz:
+  type: qux
+"""
+    expected = """
+foo:
+  display_label: Foo
+  type: bar
+baz:
+  display_label: Baz
+  type: qux
+"""
+
+    fix_indentation_file = get_file(content)
+    problems = [
+        LintProblem(
+            line=2,
+            column=0,
+            desc=' is missing a display_label.',
+            rule='inputs',
+            file=fix_indentation_file.name
+        ),
+        LintProblem(
+            line=4,
+            column=0,
+            desc=' is missing a display_label.',
+            rule='inputs',
+            file=fix_indentation_file.name
+        ),
     ]
-    expected = [
-        '  size:\n',
-        "    display_label: 'Size'\n",
-        '  retry_after:\n',
-        "    display_label: 'Retry After'\n",
-        '  env_name:\n',
-        "    display_label: 'Env Name'\n",
-    ]
-    fix_indentation_file = get_file(lines)
-    problems = []
+    fix = FixParamValue('all=-1')
+    problems[0].fixes = [fix]
+    problems[1].fixes = [fix]
     try:
-        for i in range(0, len(lines)):
-            problem = LintProblem(
-                line=i+1,
-                column=0,
-                desc=' is missing a display_label.',
-                rule='inputs',
-                file=fix_indentation_file.name
-            )
-            problems.insert(i, problem)
         add_label.fix_add_label(problems)
     finally:
         f = open(fix_indentation_file.name, 'r')
-        result_lines = f.readlines()
+        result = f.read()
         f.close()
         os.remove(fix_indentation_file.name)
-    assert expected == result_lines
+    assert expected == result
 
 
 def test_fix_indentation():
@@ -162,6 +178,76 @@ def test_fix_indentation():
     assert expected == result_lines
 
 
+def test_braces():
+    lines = [
+        '{   They wanna get my      } \n',
+        '{They wanna get my gold on the ceiling}\n',
+        "{     I ain't blind, just a matter of time  }   \n",
+        '{ Before you steal it }         \n',
+        "{Its all right, ain't no guarding my high   }   \n"
+    ]
+    expected_lines = [
+        '{ They wanna get my } \n',
+        '{They wanna get my gold on the ceiling}\n',
+        "{ I ain't blind, just a matter of time }   \n",
+        '{ Before you steal it }         \n',
+        "{Its all right, ain't no guarding my high }   \n"
+    ]
+    fix_braces_file = get_file(lines)
+
+    try:
+        for i in range(0, len(lines)):
+            problem = LintProblem(
+                line=i,
+                column=0,
+                desc='too many spaces inside braces',
+                rule='braces',
+                file=fix_braces_file.name
+            )
+            brackets.fix_spaces_in_brackets(problem)
+    finally:
+        f = open(fix_braces_file.name, 'r')
+        result_lines = f.readlines()
+        f.close()
+        os.remove(fix_braces_file.name)
+    assert result_lines == expected_lines
+
+
+def test_brackets():
+    lines = [
+        '[   They wanna get my      ] \n',
+        '[They wanna get my gold on the ceiling]\n',
+        "[     I ain't blind, just a matter of time  ]   \n",
+        '[ Before you steal it ]         \n',
+        "[Its all right, ain't no guarding my high   ]   \n"
+    ]
+    expected_lines = [
+        '[ They wanna get my ] \n',
+        '[They wanna get my gold on the ceiling]\n',
+        "[ I ain't blind, just a matter of time ]   \n",
+        '[ Before you steal it ]         \n',
+        "[Its all right, ain't no guarding my high ]   \n"
+    ]
+    fix_brackets_file = get_file(lines)
+
+    try:
+        for i in range(0, len(lines)):
+            problem = LintProblem(
+                line=i,
+                column=0,
+                desc='too many spaces inside brackets',
+                rule='brackets',
+                file=fix_brackets_file.name
+            )
+            brackets.fix_spaces_in_brackets(problem)
+    finally:
+        f = open(fix_brackets_file.name, 'r')
+        result_lines = f.readlines()
+        f.close()
+        os.remove(fix_brackets_file.name)
+    assert result_lines == expected_lines
+
+
 def test_trailing_spaces():
     lines = [
         'They wanna get my      \n',
@@ -273,6 +359,8 @@ def test_empty_lines():
                 rule='trailing-spaces',
                 file=fix_empty_lines_file.name
             )
+            fix = FixParamValue('all=-1')
+            problem.fixes = [fix]
             empty_lines.fix_empty_lines(problem)
     finally:
         f = open(fix_empty_lines_file.name, 'r')
